@@ -47,14 +47,14 @@ class RestoreBackupKeyspace(object):
 
             list=client_s3.list_objects(Bucket=self.s3, Prefix=self.snapshot_folder)['Contents']
             
-            print('Copying files from s3: ' + self.s3)
-            for s3_key in list:
-                s3_object = s3_key['Key']
-                # creating folder for object
-                os.makedirs(os.path.dirname(s3_object), exist_ok=True)
-                # copy object from s3 to local folder
-                client_s3.download_file(self.s3, s3_object, s3_object)
-                print('Downloaded: ' + s3_object)
+            # print('Copying files from s3: ' + self.s3)
+            # for s3_key in list:
+            #     s3_object = s3_key['Key']
+            #     # creating folder for object
+            #     os.makedirs(os.path.dirname(s3_object), exist_ok=True)
+            #     # copy object from s3 to local folder
+            #     client_s3.download_file(self.s3, s3_object, s3_object)
+            #     print('Downloaded: ' + s3_object)
 
             # Get user/password credentials
             if self.ssm_secret:
@@ -163,6 +163,7 @@ class RestoreBackupKeyspace(object):
                         for row in data:
                             # print(row)
                             for i in range(len(row)):
+                                print(data_types_list[i])
                                 if row[i]== 'null':
                                     row[i] = None
                                 elif data_types_list[i] == 'timestamp':
@@ -180,9 +181,9 @@ class RestoreBackupKeyspace(object):
                                         row[i] = None
                                         print(e)
                                 elif data_types_list[i] == 'boolean':
-                                    if row[i] == ('True' or 'true'):
+                                    if row[i] == 'True':
                                         row[i] = True
-                                    elif row[i] == ('Fasle' or 'false'):
+                                    elif row[i] == 'False':
                                         row[i] = False
                                     else:
                                         row[i] = None  
